
# SGX Cloud Stack Deployment

Helps to deploy SGX components on `Virtualized` and `Kubernetes/Container` Linux stacks. To facilitate the deployment process, this guide leverages in [Ansible](https://docs.ansible.com/ansible/latest/index.html#). Ansible is an IT automation tool. It can configure systems, deploy software, and orchestrate more advanced IT tasks.

- [stacks](./stacks): Provides the playbooks to deploy the full foundational stacks.
- [demos](./demos): Provides additional demo playbooks to create VM instances or deploying container workloads on Linux foundational stacks.

![](./docs/deployment_flow.png)

**_NOTE:_** Please read the SGX deployment and release document for detail steps.

## Roles

| Ansible Role | Description |
| ------------ | ----------- |
| [ansible-role-sgx-stack](./stacks/roles/ansbile-role-sgx-stack) | Install SGX SW for Virtualization and Kubernetes stacks |
| [ansible-role-sgx-dcap](./stacks/roles/ansbile-role-sgx-dcap) | Install SGX DCAP components |
| [ansbile-role-sgx-vm](./stacks/roles/ansible-role-sgx-vm) | Manage the SGX VM |

## Playbooks

| Ansible Playbook | Description |
| ---------------- | ----------- |
| [kvm-host.yml](./stacks/kvm-host.yml) | Setup KVM host stack with SGX |
| [kubernetes.yml](./stacks/kubernetes.yml) | Setup Kubernetes stack with SGX |

## Quick Start

## Build container docker-playbook
The [docker-playbook.sh](./docker-playbook.sh) allow to run ansible-playbook from a docker container.

- When running docker-playbook.sh at first time, it will create a container `ansible-playbook` automatically.
- If want to rebuild the container, please run
    ```
    ./docker-playbook.sh rebuild
    ```
**_NOTE:_**
- Assume the docker has been installed on the controller node.
- Assume the current user belong to docker group to run docker command.

## Examples:

**_NOTE:_** In real deployment, there are lots of role's variable need to be set,
please get information from ansbile role's README.

- Deploy KVM host stack with SGX

```
./docker-playbook.sh hosts stacks/kvm-host.yml
```

- Create VM with SGX
```
./docker-playbook.sh demos/create-sgx-vm.yml
```

- Deploy Kubernetes stack on Kubernete master node with SGX
```
./docker-playbook.sh stacks/kubernetes.yml
```

- Deploy Kubernetes stack on Kubernete slave node with SGX

```
./docker-playbook.sh stacks/kubernetes.yml -e “k8s_role=slave” -e 'kubernetes_join_command="kubeadm join 10.239.85.45:6443 --token 1ddbem.v1tikqrbutr6sq7e --discovery-token-ca-cert-hash sha256:b02cba3d2c98aebbd0f26be97af19fee68ae3fcb1f2f2a04b684160f534edb32"'
```
