# Kubernetes Deployment

Deploy Kubernetes master and nodes.

## Playbook Variables

| Variable Name | Description | Default |
| ------------- | ----------- | ------- |
| `kubernetes_role` | Deploy master/node | `master` |
| `k8s_username` | Non-root user account name | `k8s_master`|
| `k8s_password` | Non-root user accout password | `k8s_master`|
| `k8s_plugins_url` | Version of installed SGX pugins |<https://github.com/intel/intel-device-plugins-for-kubernetes/archive/refs/tags/v0.22.0.tar.gz> |
| `k8s_web_ui_create` |Create Kubernetes Web Dashboard | `true` |
| `k8s_web_ui_manifest_file` | Web Dashboard version to create | <https://raw.githubusercontent.com/kubernetes/dashboard/v2.2.0/aio/deploy/recommended.yaml> |
| `k8s_web_ui_enable_skip_login` |Allow read-only login to Dashboard without user credentials | `true` |
| `k8s_web_ui_banner` | Optionally displayed banner | `Kubernetes with SGX support`|
| `k8s_web_ui_port` | Assign fixed Web Dashboard port. There are no range checks, so you should know what you are doing. | random |

## Deploy Kubernetes Master Node

Example command to deploy master node:

``` bash
./docker-playbook.sh stacks/kubernetes.yml -i host-master \
 -e "sgx_repo_file_url=https://download.01.org/intelsgxstack/2021-12-08/rhel/intelsgxstack.repo"
 ```

After the Kubernetes master is deployed, the playbook will display URL for Kubernetes Web Dashboard and
administartor login token.

![Kuberentes Web UI Login dialog](./images/web_ui_login.png)

To sign in as administrator, paste in the login token. You can use `Skip` for view-only dashboard mode.
You can also generate the token manually using the command:

```bash
kubectl -n kubernetes-dashboard get secret \
$(kubectl -n kubernetes-dashboard get sa/admin-user -o jsonpath="{.secrets[0].name}") \
-o go-template="{{.data.token | base64decode}}"

```

## Deploy Kubernetes Worker Nodes

It is also possible to create a master node with multiple worker nodes that are automatically joined in. For example, deploying target nodes with the following host inventory file will deploy master and two nodes:

```text
10.165.56.215 ansible_user=sgxdev kubernetes_role=master
10.165.56.239 ansible_user=sgxdev kubernetes_role=node
10.165.58.159 ansible_user=sgxdev kubernetes_role=node
```

Create a k8s cluster with master node and two worker nodes by using the above inventory file:

``` bash
./docker-playbook.sh stacks/kubernetes.yml -i host-master-worker-nodes  \
 -e "sgx_repo_file_url=https://download.01.org/intelsgxstack/2021-12-08/rhel/intelsgxstack.repo"
 ```

You can pass additional variables at the same time, for example:

``` bash
./docker-playbook.sh stacks/kubernetes.yml -i host-master-worker-nodes  \
 -e "sgx_repo_file_url=https://download.01.org/intelsgxstack/2021-12-08/rhel/intelsgxstack.repo" \
 -e "k8s_username=joe" -e "k8s_password=intelsgx" -e "k8s_web_ui_banner=SGX" \
 -e "k8s_web_ui_port=32080"
```

When deploying the Kubernetes master, the `kubernetes.yml` playbook will display the command for additional nodes to join the master as the last message.

NOTE: The join command init token can expire. You can obtain a fresh token by issuing
the following command in Kubernetes **master node**:

```bash
kubeadm token create --print-join-command
```

You need to issue this join command on each additional **worker** node you want to join the existing cluster.
