# ansible-role-sgx-vm

Create/Destroy a SGX VM on SGX KVM host

## Role Variables

| Variable | Description | Default |
| -------- | ----------- | ------- |
| `vm_action` | Create or destroy action, one of [`create`\|`destroy`] | `create` |
| `vm_location` | The directory of VM image on the KVM host | `/var/lib/libvirt/images/` |
| `vm_image` | The file name of VM image on the KVM host | `CentOS-8-GenericCloud-8.4.2105-20210603.0.x86_64.qcow2` |
| `vm_image_url` | The remote download URL for VM image | `https://cloud.centos.org/centos/8/x86_64/images/CentOS-8-GenericCloud-8.4.2105-20210603.0.x86_64.qcow2` |
| `vm_os_variant` | VM os variant.  Should be one of reported by "osinfo-query os" [^1]| `centos8`|
| `vm_root_password` | The root password for demo VM image| `Intelinux123` |
| `vm_resize_partition` | Disk partition to resize [^2] | `/dev/sda1` |
| `vm_kernel` | Linux kernel for VMs [^3]| `kernel` |
| `vm_guests` | List of VM configurations | See below "VM Template" |
| `vm_repo_file_url` | URL of an additional repo file to be used to install packages to VM (optional)| None |
| `vm_no_log` | Keep sensitive values out of logs | `true` |
| `copy_host_files`| Copy files from Host to VMs [^4] | empty |
| `sm_username` | User name (ID) for RHEL subscription manager [^5]| None |
| `sm_password` | User password for RHEL subscription manager [^5]| None |

[^1]:  Currently suported values are: `centos8`, `rhel8.4` and `rhel8.5`

[^2]:  EFI based images typically need `/dev/sda3`

[^3]: If `vm_kernel` is specified as an empty string, no new kernel is installed in VMs.

[^4]: Implemented via `virt-customize --copy-in`, for details see <https://libguestfs.org/virt-customize.1.html>

[^5]: Values for username/password obtained by subscribing to Red Hat at <https://www.redhat.com>

### Variables for vm_guests

| Name | Description | Default | Notes |
| ---- | ----- | ------------- | ---- |
| `name` | domain name of the VM | must be specified | compulsory, if domain already exists then new VM creation is ignored|
| `hostname` | hostname of the VM  |  must be specified  |  compulsory |
| `memory_kib` | amount of RAM for VM | must be specified  | compulsory, no checks for overcommitment |
| `vcpu` | number of CPUs | 2 | no checks for overcommitment |
| `qcow_disk_file` | disk file name | `name`.qcow2 | |
| `disk_size` | disk size in GB | none | Shrinking of an image is ignored. No resizing of VM image if `disk_size` not defined|
| `mac_address` | MAC address of VM | '52:54:00:xx:yy:zz' with xx:yy:zz randomized| |
| `autostart` |start VM automatically after host reboot |`yes` | optional| |
| `running` | start VM after VM created  |`yes` | optional | |
| `epc_size` | SGX EPC size | `512M`| |
| `customize_extra` | commands to pass to `virt-customize`| empty | optionally customize individual VMs (create users, ssh access,...) [^6]|

[^6] See the complete list of available commands here: <https://libguestfs.org/virt-customize.1.html>

## VM Template

```
vm_guests:
  - name : vm01
    hostname : 'test-vm01'
    memory_kib: 16777216
    vcpu: 4
    qcow_disk_file: 'test-vm01.qcow2'
    mac_address: '52:54:00:c5:9e:e6'
    autostart: 'yes'
    epc_size: '256M'
    disk_size: '12G'
  - name : vm02
    hostname : 'test-vm02'
    memory_kib: 16777216
    vcpu: 8
    qcow_disk_file: 'test-vm02.qcow2'
    mac_address: '52:54:00:c5:9e:e7'
    autostart: 'no'
    epc_size: '512M'
    disk_size: '20G'
```

## Dependencies

ansible-role-sgx-stack
